@@ -31,13 +31,13 @@ class QgsExpression;
 class QgsGeometry;
 class QgsPointXY;
 class QgsRectangle;
+class QgsVectorLayer;
 
 #include "qgsgeometry.h"
 #include "qgsexpression.h"
 #include "qgsexpressionnode.h"
 #include "qgsexpressionnodeimpl.h"
 #include "qgssqlstatement.h"
-#include "qgsvectorlayer.h"
 
 /**
  * \ingroup core
@@ -161,6 +161,15 @@ class CORE_EXPORT QgsOgcUtils
       FILTER_FES_2_0
     };
 
+    /**
+     * Returns an expression from a WFS filter embedded in a document.
+     * \param element The WFS Filter
+     * \param version The WFS version
+     * \param layer Layer to use to retrieve field values from literal filters
+     * \since QGIS 3.4
+     */
+    static QgsExpression *expressionFromOgcFilter( const QDomElement &element, FilterVersion version, QgsVectorLayer *layer = nullptr ) SIP_FACTORY;
+
     /**
      * Creates OGC filter XML element. Supports minimum standard filter
      * according to the OGC filter specs (=,!=,<,>,<=,>=,AND,OR,NOT)
@@ -338,7 +347,7 @@ class QgsOgcUtilsExprToFilter
                              bool invertAxisOrientation );
 
     //! Convert an expression to a OGC filter
-    QDomElement expressionNodeToOgcFilter( const QgsExpressionNode *node );
+    QDomElement expressionNodeToOgcFilter( const QgsExpressionNode *node, QgsExpression *expression, const QgsExpressionContext *context );
 
     //! Returns whether the gml: namespace is used
     bool GMLNamespaceUsed() const { return mGMLUsed; }
@@ -359,12 +368,99 @@ class QgsOgcUtilsExprToFilter
     QString mPropertyName;
     int mGeomId;
 
-    QDomElement expressionUnaryOperatorToOgcFilter( const QgsExpressionNodeUnaryOperator *node );
-    QDomElement expressionBinaryOperatorToOgcFilter( const QgsExpressionNodeBinaryOperator *node );
-    QDomElement expressionLiteralToOgcFilter( const QgsExpressionNodeLiteral *node );
-    QDomElement expressionColumnRefToOgcFilter( const QgsExpressionNodeColumnRef *node );
-    QDomElement expressionInOperatorToOgcFilter( const QgsExpressionNodeInOperator *node );
-    QDomElement expressionFunctionToOgcFilter( const QgsExpressionNodeFunction *node );
+    QDomElement expressionUnaryOperatorToOgcFilter( const QgsExpressionNodeUnaryOperator *node, QgsExpression *expression, const QgsExpressionContext *context );
+    QDomElement expressionBinaryOperatorToOgcFilter( const QgsExpressionNodeBinaryOperator *node, QgsExpression *expression, const QgsExpressionContext *context );
+    QDomElement expressionLiteralToOgcFilter( const QgsExpressionNodeLiteral *node, QgsExpression *expression, const QgsExpressionContext *context );
+    QDomElement expressionColumnRefToOgcFilter( const QgsExpressionNodeColumnRef *node, QgsExpression *expression, const QgsExpressionContext *context );
+    QDomElement expressionInOperatorToOgcFilter( const QgsExpressionNodeInOperator *node, QgsExpression *expression, const QgsExpressionContext *context );
+    QDomElement expressionFunctionToOgcFilter( const QgsExpressionNodeFunction *node, QgsExpression *expression, const QgsExpressionContext *context );
+};
+
+/**
+ * \ingroup core
+ * \brief Internal use by QgsOgcUtils
+ * \note not available in Python bindings
+ * \since QGIS 3.4
+ */
+class QgsOgcUtilsExpressionFromFilter
+{
+  public:
+
+    /**
+     * Constructor for QgsOgcUtilsExpressionFromFilter.
+     * \param version WFS Version
+     * \param layer Layer to use to retrieve field values from literal filters
+     */
+    QgsOgcUtilsExpressionFromFilter( QgsOgcUtils::FilterVersion version = QgsOgcUtils::FILTER_OGC_1_0,
+                                     const QgsVectorLayer *layer = nullptr );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document
+     * element. A null pointer is returned when an error happened.
+     * \param element The WFS filter
+     */
+    QgsExpressionNode *nodeFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns the underlying error message, or an empty string in case of no
+     * error.
+     */
+    QString errorMessage() const;
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * binary operators.
+     *
+     */
+    QgsExpressionNodeBinaryOperator *nodeBinaryOperatorFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * spatial operators.
+     */
+    QgsExpressionNodeFunction *nodeSpatialOperatorFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * column references.
+     */
+    QgsExpressionNodeColumnRef *nodeColumnRefFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * literal tag.
+     */
+    QgsExpressionNode *nodeLiteralFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * Not operator.
+     */
+    QgsExpressionNodeUnaryOperator *nodeNotFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * IsNull operator.
+     */
+    QgsExpressionNodeBinaryOperator *nodePropertyIsNullFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * functions.
+     */
+    QgsExpressionNodeFunction *nodeFunctionFromOgcFilter( const QDomElement &element );
+
+    /**
+     * Returns an expression node from a WFS filter embedded in a document with
+     * boudnaries operator.
+     */
+    QgsExpressionNode *nodeIsBetweenFromOgcFilter( const QDomElement &element );
+
+  private:
+    const QgsVectorLayer *mLayer = nullptr;
+    QString mErrorMessage;
+    QString mPropertyName;
+    QString mPrefix;
 };
 
 /**
