@@ -114,6 +114,15 @@ class CORE_EXPORT QgsTask : public QObject
      */
     double progress() const { return mTotalProgress; }
 
+    /**
+     * Returns the elapsed time since the task commenced, in milliseconds.
+     *
+     * The value is undefined for tasks which have not begun.
+     *
+     * \since QGIS 3.4
+     */
+    qint64 elapsedTime() const;
+
     /**
      * Notifies the task that it should terminate. Calling this is not guaranteed
      * to immediately end the task, rather it sets the isCanceled() flag which
@@ -195,7 +204,7 @@ class CORE_EXPORT QgsTask : public QObject
      *
      * The result will be false if the wait timed out and true in any other case.
      */
-    bool waitForFinished( unsigned long timeout = 30000 );
+    bool waitForFinished( int timeout = 30000 );
 
   signals:
 
@@ -303,8 +312,6 @@ class CORE_EXPORT QgsTask : public QObject
     bool mShouldTerminate = false;
     int mStartCount = 0;
 
-    QWaitCondition mTaskFinished;
-
     struct SubTask
     {
       SubTask( QgsTask *task, const QgsTaskList &dependencies, SubTaskDependency dependency )
@@ -320,6 +327,8 @@ class CORE_EXPORT QgsTask : public QObject
 
     QgsWeakMapLayerPointerList mDependentLayers;
 
+    QElapsedTimer mElapsedTime;
+
 
     /**
      * Starts the task. Should not be public as only QgsTaskManagers can initiate tasks.
