@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 from osgeo import gdal
 from qgis.PyQt.QtCore import QVariant
@@ -107,6 +107,10 @@ class PointsFromLines(QgisAlgorithm):
         for current, f in enumerate(features):
             if feedback.isCanceled():
                 break
+
+            if not f.hasGeometry():
+                continue
+
             geom = f.geometry()
             if geom.isMultipart():
                 lines = geom.asMultiPolyline()
