@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '1edf372fb80f2a35c77b128dc143c0f3c97cd8f3'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 from datetime import datetime
@@ -144,10 +144,10 @@ class PointsToPaths(QgisAlgorithm):
 
             point = f.geometry().constGet().clone()
             if group_field_index >= 0:
-                group = f.attributes()[group_field_index]
+                group = f[group_field_index]
             else:
                 group = 1
-            order = f.attributes()[order_field_index]
+            order = f[order_field_index]
             if date_format != '':
                 order = datetime.strptime(str(order), date_format)
             if group in points:
@@ -165,7 +165,7 @@ class PointsToPaths(QgisAlgorithm):
 
         current = 0
         total = 100.0 / len(points) if points else 1
-        for group, vertices in list(points.items()):
+        for group, vertices in points.items():
             if feedback.isCanceled():
                 break
 
