@@ -23,7 +23,7 @@ __copyright__ = '(C) 201, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 import shutil
@@ -53,7 +53,7 @@ class AddModelFromFileAction(ToolboxAction):
         lastDir = settings.value('Processing/lastModelsDir', '')
         filename, selected_filter = QFileDialog.getOpenFileName(self.toolbox,
                                                                 self.tr('Open Model', 'AddModelFromFileAction'), lastDir,
-                                                                self.tr('Processing model files (*.model3 *.MODEL3)', 'AddModelFromFileAction'))
+                                                                self.tr('Processing models (*.model3 *.MODEL3)', 'AddModelFromFileAction'))
         if filename:
             settings.setValue('Processing/lastModelsDir',
                               QFileInfo(filename).absoluteDir().absolutePath())
